/*
 * libsyncml - A syncml protocol implementation
 * Copyright (C) 2005  Armin Bauer <armin.bauer@opensync.org>
 * Copyright (C) 2008  Michael Bell <michael.bell@opensync.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
 *
 */

/**
 * @defgroup SmlObjectAuth SyncML Authentication Object
 * @ingroup PublicObjectAPI
 * @brief The public part
 * 
 */
/*@{*/

#ifndef _SML_AUTH_H_
#define _SML_AUTH_H_

typedef struct SmlAuthenticator SmlAuthenticator;
typedef SmlBool (* SmlAuthVerifyCb)(SmlChal *chal, SmlCred *cred, const char *username, void *userdata, SmlError **error);

SmlAuthenticator *smlAuthNew(SmlError **error);
void smlAuthFree(SmlAuthenticator *auth);
SmlBool smlAuthRegister(SmlAuthenticator *auth, SmlManager *manager, SmlError **error);
void smlAuthSetState(SmlAuthenticator *auth, SmlErrorType type);
void smlAuthSetVerifyCallback(SmlAuthenticator *auth, SmlAuthVerifyCb callback, void *userdata);
void smlAuthSetEnable(SmlAuthenticator *auth, SmlBool enabled);
SmlBool smlAuthIsEnabled(SmlAuthenticator *auth);

/* This can be used from within the SmlAuthVerifyCb to do the authentication itself. */
SmlBool smlAuthVerify(SmlChal *chal, SmlCred *cred, const char *username, const char *password, SmlError **error);

/* set required authentication type if this is a server */
void smlAuthSetType(SmlAuthenticator *auth, SmlAuthType code);

/* expire date: 20090813 */
SmlStatus *smlAuthHeaderReply(SmlSession *session, SmlAuthType code, SmlError **error) LIBSYNCML_DEPRECATED;

#endif //_SML_AUTH_H_
/*@}*/
