/*
 * libsyncml - A syncml protocol implementation
 * Copyright (C) 2005  Armin Bauer <armin.bauer@opensync.org>
 * Copyright (C) 2008  Michael Bell <michael.bell@opensync.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
 *
 */

/**
 * @defgroup SmlBase64 SyncML Base64 (DEPRECATED)
 * @ingroup PublicLowLevelAPI
 * @brief The public part
 * 
 */
/*@{*/

#ifndef _SML_BASE64_H_
#define _SML_BASE64_H_

/* expire date: 20091028 */
SmlBool smlBase64Decode(const char *input, char **output, unsigned int *outsize, SmlError **error) LIBSYNCML_DEPRECATED;
SmlBool smlBase64DecodeBinary(const char *input, unsigned int size, char **output, unsigned int *outsize, SmlError **error) LIBSYNCML_DEPRECATED;

SmlBool smlBase64Encode(const char *input, char **output, SmlError **error) LIBSYNCML_DEPRECATED;
SmlBool smlBase64EncodeBinary(const char *input, unsigned int size, char **output, SmlError **error) LIBSYNCML_DEPRECATED;

#endif //_SML_BASE64_H_

/*@}*/
